'''
Cafe Ban v1.6
Written by RideGuy & XE_ManUp
Credit to Wally3k for the new parsing system concept of steamid game pages
Originally requested by Hacker Killer

Kicks and bans all players who's SteamID matches the criteria of a Cyber Cafe
Steam Account (starts with 7 and is 7 digits long) and has a community game
page of a cafe account. Includes a "white list" for both steamid's
(steamidwhitelist.txt) and IP's (ipwhitelist.txt) so you can make exceptions
to the rule. Includes a "banned list" (bannedlist.txt) that records all
SteamIDs that are banned by CafeBans.
'''

import es
import urllib2
import socket

# Average query time for a real player on an empyt listen server was about 1.5 - 1.75 seconds
timeout = 5
socket.setdefaulttimeout(timeout)
es.ServerVar('cafeban', 1.6).makepublic()

bantype = es.ServerVar('cafeban_bantype', 0, 'Action taken by CafeBan.  0 = verbose only, 1 = kick and ban, 2 = kick only')
whiteList = {'steamid':[], 'ip':[]}

def load():
    es.server.cmd('exec cafeban/cafeban.cfg')
    
    whiteList['steamid'] = getWhiteList('steamid')
    whiteList['ip'] = getWhiteList('ip')

def es_map_start(event_var):
    whiteList['steamid'] = getWhiteList('steamid')
    whiteList['ip'] = getWhiteList('ip')

def player_activate(event_var):
    steamid = event_var['es_steamid']
    userid = event_var['userid']
    
    ip = es.createplayerlist(userid)[int(userid)]['address']
    if  ip[:-6] in whiteList['ip']:
        return
    
    if steamid == 'STEAM_ID_LAN':
        return
    
    if steamid == 'BOT':
        return
    
    if steamid == 'STEAM_ID_PENDING':
        es.server.queuecmd('kickid %s "Steamid still pending. Retry please."' % userid)
        return
    
    if len(steamid) != 17:
        return
    
    if steamid[10:11] != '7':
        return
    
    if steamid in whiteList['steamid']:
        return
    
    # Retrieve the Steam Community URL
    serverid = steamid[8]
    steamid = steamid.replace('STEAM_0:' + serverid + ':', '')
    communityid = int(steamid) * 2 + int(serverid) + 76561197960265728
    url = 'http://steamcommunity.com/profiles/%d/games' % communityid
    
    # Open and read the Steam Community URL
    res = urllib2.urlopen(url)
    page = res.read()
    res.close()
    
    if page.count('<h4>') < 100:
        return
    
    playerName = event_var['es_username']
    
    # Ban the player
    if bantype == '2':
        es.server.queuecmd('banid 0 %s' % steamid)
        es.server.queuecmd('writeid')
        es.server.queuecmd('kickid %s "Banned for using a Cafe Account"' % userid)
        bannedListFile = open(es.getAddonPath('cafeban') + '/bannedlist.txt', 'a')
        bannedListFile.write('%s - %s\n' % (steamid, playerName))
        bannedListFile.close()
    # Kick the player
    elif bantype == '1':
        es.server.queuecmd('kickid %s "Kicked for using a Cafe Account"' % userid)
    # No action, print to console
    else:
        es.dbgmsg(0, 'Player %s (%s): Not kicked or banned. cafeban_bantype not set to 1 or 2.' %(playerName, steamid))

def getWhiteList(whiteListType):
    whiteListFile = open(es.getAddonPath('cafeban') + '/%swhitelist.txt' % whiteListType, 'r')
    whiteList = []
    for line in whiteListFile:
        line = line.strip()
        if not line.startswith('//') and line != '':
            whiteList.append(line)
    return whiteList